# Lexer Python SDK

Welcome to Lexer!
We build tools designed to help machine learning engineers code models with
confidence.

By using this Python SDK, you can:

1. Compare machine learning execution engines
2. Understand model performance before deploying to production, and
3. Save yourself and colleagues countless hours of headaches ensuring
models perform as expected!

Please refer to our official documentation [here](https://docs.lexer.ai/docs)
for installation and more usage details.
